@@ -6,7 +6,7 @@ import traceback
 from asyncio import StreamReader, StreamWriter
 from base64 import urlsafe_b64decode
 from binascii import hexlify
-from typing import Callable, Optional, Union, AsyncGenerator
+from typing import AsyncGenerator, Callable, Optional, Union
 
 import cryptography.hazmat.primitives.serialization as serialization
 import http_ece
@@ -14,8 +14,8 @@ from cryptography.hazmat.backends import default_backend
 from loguru import logger
 
 from pullkin.client_base import PullkinBase
-from pullkin.proto.mcs_proto import *
 from pullkin.models.message import Message
+from pullkin.proto.mcs_proto import *  # noqa: F403
 
 logger.disable("pullkin")
 
@@ -25,13 +25,13 @@ class AioPullkin(PullkinBase):
         super().__init__()
         self.__reader: Optional[StreamReader] = None
         self.__writer: Optional[StreamWriter] = None
-        self.credentials: dict = {}
         self.persistent_ids: list = []
         self.callback: Callable = None
         self.on_notification_handlers: list = []
         self.once = True
+        self._started = False
 
-    def on_notification(self, filter: Callable = lambda *a, **k: True):
+    def on_notification(self, handler_filter: Callable = lambda *a, **k: True):
         """
         Decorator
 
@@ -61,14 +61,14 @@ class AioPullkin(PullkinBase):
 
         def decorator(callback):
             self.on_notification_handlers.append(
-                {"callback": callback, "filter": filter}
+                {"callback": callback, "filter": handler_filter}
             )
             return callback
 
         return decorator
 
     def register_on_notification_handler(
-        self, filter: Callable = None, callback: Callable = None
+        self, handler_filter: Callable = None, callback: Callable = None
     ):
         """
         Function
@@ -99,7 +99,9 @@ class AioPullkin(PullkinBase):
                 print("=-)")
 
         """
-        self.on_notification_handlers.append({"callback": callback, "filter": filter})
+        self.on_notification_handlers.append(
+            {"callback": callback, "filter": handler_filter}
+        )
 
     async def __run_on_notification_callbacks(self, obj, notification, data_message):
         x = 0
@@ -120,16 +122,15 @@ class AioPullkin(PullkinBase):
                     self.callback(obj, notification, data_message)
 
         if not x:
-            logger.debug('No one callback was called')
+            logger.debug("No one callback was called")
 
-    @classmethod
-    async def aioregister(cls, sender_id):
+    async def aioregister(self, sender_id):
         """
         Async version. Register "app" for receive pushed
 
         Returns "app"-credential in dict for receive "personal" push by token
         """
-        return await cls._register(sender_id)
+        return await self._register(sender_id)
 
     async def __open_connection(self) -> None:
         import ssl
@@ -160,7 +161,7 @@ class AioPullkin(PullkinBase):
         return res
 
     async def __aiosend(self, packet) -> None:
-        logger.debug(f"Send")
+        logger.debug("Send")
         header = bytearray([self.MCS_VERSION, self.PACKET_BY_TAG.index(type(packet))])
         logger.debug(f"Packet:\n'{packet}'")
         payload = packet.SerializeToString()
@@ -170,7 +171,7 @@ class AioPullkin(PullkinBase):
         await self.__writer.drain()
 
     async def __aiorecv(self, first=False) -> Optional[PullkinBase.packet_union]:
-        logger.debug(f"Receive")
+        logger.debug("Receive")
         if first:
             version, tag = struct.unpack("BB", await self.__aioread(2))
             logger.debug(f"Version {version}")
@@ -193,7 +194,7 @@ class AioPullkin(PullkinBase):
 
     async def __aiolisten_once(
         self,
-    ) -> None:
+    ) -> Message:
         load_der_private_key = serialization.load_der_private_key
 
         p = await self.__aiorecv()
@@ -210,9 +211,9 @@ class AioPullkin(PullkinBase):
         salt = salt[5:]  # strip salt=
         crypto_key = urlsafe_b64decode(crypto_key.encode("ascii"))
         salt = urlsafe_b64decode(salt.encode("ascii"))
-        der_data = self.credentials["keys"]["private"]
+        der_data = self.credentials.keys.private
         der_data = urlsafe_b64decode(der_data.encode("ascii") + b"========")
-        secret = self.credentials["keys"]["secret"]
+        secret = self.credentials.keys.secret
         secret = urlsafe_b64decode(secret.encode("ascii") + b"========")
         privkey = load_der_private_key(
             der_data, password=None, backend=default_backend()
@@ -227,24 +228,26 @@ class AioPullkin(PullkinBase):
         )
         notification = Message(json.loads(decrypted.decode("utf-8")))
         await self.__run_on_notification_callbacks({}, notification, p)
+        return notification
 
-    async def __aiolisten_start(self) -> None:
-        await self.gcm_check_in(**self.credentials["gcm"])
+    async def _aiolisten_start(self) -> None:
+        await self.gcm_check_in(self.credentials.gcm)
         req = LoginRequest()
         req.adaptive_heartbeat = False
         req.auth_service = 2
-        req.auth_token = self.credentials["gcm"]["securityToken"]
+        req.auth_token = self.credentials.gcm.securityToken
         req.id = "chrome-91.0.3234.0"
         req.domain = "mcs.android.com"
-        req.device_id = "android-%x" % int(self.credentials["gcm"]["androidId"])
+        req.device_id = "android-%x" % int(self.credentials.gcm.androidId)
         req.network_type = 1
-        req.resource = self.credentials["gcm"]["androidId"]
-        req.user = self.credentials["gcm"]["androidId"]
+        req.resource = self.credentials.gcm.androidId
+        req.user = self.credentials.gcm.androidId
         req.use_rmq2 = True
         req.setting.append(Setting(name="new_vc", value="1"))
         req.received_persistent_id.extend(self.persistent_ids)
         await self.__aiosend(req)
         await self.__aiorecv(first=True)
+        self._started = True
 
     async def __aiolisten_coroutine(self) -> AsyncGenerator:
         while True:
@@ -275,11 +278,32 @@ class AioPullkin(PullkinBase):
         """
         if not (self.__reader or self.__writer):
             await self.__open_connection()
-        await self.__aiolisten_start()
+        await self._aiolisten_start()
         coroutine = self.__aiolisten_coroutine()
         return coroutine
 
-    async def listen_forever(self, timer: Union[int, float] = 0.05) -> None:
+    async def _wait_start(self):
+        while not all([self._started, self.__reader, self.__writer]):
+            await asyncio.sleep(0.1)
+
+    async def _run_listener(self, timer: Union[int, float] = 0.05) -> None:
+        if not (self.__reader or self.__writer):
+            await self.__open_connection()
+
+        await self._aiolisten_start()
+        coroutine = self.__aiolisten_coroutine()
+        try:
+            while self.__reader and self.__writer:
+                await coroutine.asend(None)
+                await asyncio.sleep(timer)
+        except Exception:
+            print(traceback.format_exc())
+        finally:
+            if self.__writer:
+                self.__writer.close()
+                await self.__writer.wait_closed()
+
+    async def run(self, timer: Union[int, float] = 0.05) -> None:
         """
         Listens for push notifications
 
@@ -288,21 +312,12 @@ class AioPullkin(PullkinBase):
         :param timer: timer in seconds between receive iteration
         :type timer: ``int`` or ``float``, optional, default ``0.05``
         """
-        if not (self.__reader or self.__writer):
-            await self.__open_connection()
 
-        await self.__aiolisten_start()
-        coroutine = self.__aiolisten_coroutine()
+        asyncio.ensure_future(self._run_listener(timer))
         try:
-            while self.__reader and self.__writer:
-                await coroutine.asend(None)
-                await asyncio.sleep(timer)
-        except Exception as e:
-            print(traceback.format_exc())
-        finally:
-            if self.__writer:
-                self.__writer.close()
-                await self.__writer.wait_closed()
+            await asyncio.wait(self._wait_start(), timeout=10)
+        except asyncio.exceptions.TimeoutError:
+            print("Timeout start listener 10s")
 
     async def close(self):
         try:
