@@ -3,7 +3,7 @@ import json
 import os
 import time
 from base64 import urlsafe_b64encode
-from typing import Union
+from typing import Optional, Union
 from urllib.parse import urlencode
 
 import nest_asyncio
@@ -11,9 +11,10 @@ from httpx import AsyncClient, Request
 from loguru import logger
 from oscrypto.asymmetric import generate_pair
 
+from pullkin.models import AppCredentials, AppCredentialsGcm
 from pullkin.proto.android_checkin_proto import AndroidCheckinProto, ChromeBuildProto
 from pullkin.proto.checkin_proto import AndroidCheckinRequest, AndroidCheckinResponse
-from pullkin.proto.mcs_proto import *
+from pullkin.proto.mcs_proto import *  # noqa: F403
 
 nest_asyncio.apply()
 logger.disable("pullkin")
@@ -70,6 +71,7 @@ class PullkinBase:
 
     def __init__(self):
         self._http_client = None
+        self.credentials: AppCredentials = None
 
     @property
     def http_client(self):
@@ -89,14 +91,14 @@ class PullkinBase:
                 resp_data = resp.content
                 logger.debug(f"Response:\n{resp_data}")
                 return resp_data
-            except ValueError as e:
+            except ValueError:
                 ...
             except Exception as e:
                 logger.opt(exception=e).error("Error during request:")
                 time.sleep(1)
         raise ConnectionError(f"Error during request: {e}")
 
-    async def gcm_check_in(self, androidId=None, securityToken=None, **_):
+    async def gcm_check_in(self, credentials: Optional[AppCredentialsGcm] = None):
         """
         perform check-in request
 
@@ -118,10 +120,9 @@ class PullkinBase:
         payload.user_serial_number = 0
         payload.checkin.from_dict(checkin.to_dict())
         payload.version = 3
-        if androidId:
-            payload.id = int(androidId)
-        if securityToken:
-            payload.security_token = int(securityToken)
+        if credentials:
+            payload.id = int(credentials.androidId)
+            payload.security_token = int(credentials.securityToken)
 
         logger.debug(f"Payload:\n{payload}")
         req = self.http_client.build_request(
@@ -129,7 +130,7 @@ class PullkinBase:
             url=self.CHECKIN_URL,
             headers={"Content-Type": "application/x-protobuf"},
             content=payload.SerializeToString(),
-            timeout=5
+            timeout=5,
         )
         resp_data = await self._do_request(req)
         resp = AndroidCheckinResponse()
@@ -189,7 +190,7 @@ class PullkinBase:
             return res
         return None
 
-    async def fcm_register(self, sender_id, token, retries=5):
+    async def fcm_register(self, sender_id: Union[str, int], token, retries=5):
         """
         generates key pair and obtains a fcm token
 
@@ -215,7 +216,7 @@ class PullkinBase:
             "secret": self.urlsafe_base64(os.urandom(16)),
         }
         body = {
-            "authorized_entity": sender_id,
+            "authorized_entity": int(sender_id),
             "endpoint": "{}/{}".format(self.FCM_ENDPOINT, token),
             "encryption_key": keys["public"],
             "encryption_auth": keys["secret"],
@@ -225,7 +226,7 @@ class PullkinBase:
         resp_data = await self._do_request(req, retries)
         return {"keys": keys, "fcm": json.loads(resp_data.decode("utf-8"))}
 
-    async def _register(self, sender_id):
+    async def _register(self, sender_id: Union[str, int]):
         """register gcm and fcm tokens for sender_id"""
         app_id = "1:302251869498:android:90c5cd74bae68792813c03"
         subscription = await self.gcm_register(appId=app_id)
@@ -236,14 +237,15 @@ class PullkinBase:
         res.update(fcm)
         return res
 
-    def register(self, sender_id):
+    def register(self, sender_id: Union[str, int]):
         """
         Sync version. Register "app" for receive pushed
 
         Returns "app"-credential in dict for receive "personal" push by token
         """
         res = asyncio.get_event_loop().run_until_complete(self._register(sender_id))
-        return res
+        self.credentials = AppCredentials(**res)
+        return AppCredentials(**res)
 
     @classmethod
     def _encode_varint32(cls, x):
